;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC16F627A. This file contains the basic code              *
;   building blocks to build upon.                                    *
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    Emoticons.asm                                           *
;    Date:        March 4 2015                                                  *
;    File Version:                                                    *
;                                                                     *
;    Author:         Ron Newton                                                 *
;    Company:                                                         *
;                                                              *
;**********************************************************************
;                                                                     *
;    Files Required: P16F627A.INC                                     *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;Pin 1		RA2		NC
;Pin 2		RA3		NC
;Pin 3		RA4		NC
;Pin 4		RA5 	NC
;Pin 5		VSS		NEGATIVE
;Pin 6		RB0		LED RESISTOR
;Pin 7		RB1		LED RESISTOR
;Pin 8		RB2		LED RESISTOR
;Pin 9		RB3		LED RESISTOR
;Pin 10		RB4		LED RESISTOR
;Pin 11		RB5		LED RESISTOR
;Pin 12		RB6		LED RESISTOR
;Pin 13		RB7		LED RESISTOR
;Pin 14		VCC		3 VOLTS +
;Pin 15		RA6		NC
;Pin 16		RA7		COLUMN 3 
;Pin 17		RA0		COLUMN 1 
;Pin 18     RA1     COLUMN 2                                                          *
;**********************************************************************

	list      p=16f627A           ; list directive to define processor
	#include <p16F627A.inc>       ; processor specific variable definitions

	errorlevel  -302              ; suppress message 302 from list file

	__CONFIG   _CP_OFF &  _LVP_OFF & _BOREN_OFF & _MCLRE_OFF & _WDT_OFF & _PWRTE_OFF & _INTOSC_OSC_NOCLKOUT 

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file.
; See data sheet for additional information on configuration word settings.

#DEFINE		C1		PORTA,0
#DEFINE		C2		PORTA,1
#DEFINE		C3		PORTA,7
#DEFINE		AA		PORTB,0
#DEFINE		BB		PORTB,1
#DEFINE		CC		PORTB,2
#DEFINE		DD		PORTB,3
#DEFINE		EE		PORTB,4
#DEFINE		FF		PORTB,5
#DEFINE		GG		PORTB,6
#DEFINE		HH		PORTB,7


	CBLOCK	0X20
COUNT		;COUNTING REGISTER
COUNT1		;COUNTING REGISTER
COUNT2		;COUNTING REGISTER
COUNT3		;COUNTING REGISTER
TIMER		;COUNTING REGISTER
TIMER1		;COUNTING REGISTER
TIMER2		;COUNTING REGISTER
TIMER3		;COUNTING REGISTER
TIMER4		;COUNTING REGISTER
COUNTER
FLAG
	ENDC




;**********************************************************************
	ORG     0x000             ; processor reset vector
	goto    main              ; go to beginning of program



main
		CLRF		PORTA		;CLEARPORTA
		CLRF		PORTB		;CLEAR PORTB
		BANKSEL		TRISA		;CHANGE BANKS
		CLRF		TRISA		;CLEAR TRISA	MAKE ALL OUTPUTS
		CLRF		TRISB		;CLEAR TRISB	
		BANKSEL		PORTA		;CHANGE BANKS
		MOVLW		0x07
		MOVWF		CMCON		;MAKE ALL PORTA DIGITAL
		BANKSEL		PCON		;CHANGE BANKS
		MOVLW		B'00001000'	;MOVE 8 INTO PCON
		MOVWF		PCON		;MAKE 4 mHZ
		MOVLW		B'00001111'	;LOAD 15
		MOVWF		OPTION_REG	;WATCH DOG TIMER MAXIMUM
		BANKSEL		PORTA
		
				
;**************************TESTING AREA****************
TEST


;******************************************************

START
		MOVLW	.3
		MOVWF	TIMER1
S0		CALL	HAPPY			;GET HAPPY FACE
		DECFSZ	TIMER,1			;TIMING DELAY
		GOTO	S0
		DECFSZ	TIMER1,1
		GOTO	S0

		MOVLW	.3
		MOVWF	TIMER1
SA		CALL	SAD				;GET SAD FACE
		DECFSZ	TIMER,1
		GOTO	SA	
		DECFSZ	TIMER1,1
		GOTO	SA			

		MOVLW	.3
		MOVWF	TIMER1
S2		CALL	CLEAR			;LOOKING
		BSF		FLAG,0			;SET FLAG 0 FOR SHIFTING EYES
		MOVLW	.100
		MOVWF	TIMER
		CALL	WINK_LT			;CALL WINK_LT
		DECFSZ	TIMER,1
		GOTO	$-2
		BCF		FLAG,0			;CLEAR FLAG 0 FOR SHIFTING EYES
		MOVLW	.100
		MOVWF	TIMER
		CALL	WINK_LT			;WINK _LT
		DECFSZ	TIMER,1
		GOTO	$-2		

		DECFSZ	TIMER1,1
		GOTO	S2


		MOVLW	.3
		MOVWF	TIMER1
S1		CALL	CLEAR			;WINKING
		BSF		FLAG,0			;SET WINK FLAG
		MOVLW	.100
		MOVWF	TIMER
		CALL	WINK_RT			;WINK RIGHT
		DECFSZ	TIMER,1
		GOTO	$-2
		BCF		FLAG,0			;CLEAR WINK FLAG
		MOVLW	.50
		MOVWF	TIMER
		CALL	WINK_RT			;WINK	RIGHT
		DECFSZ	TIMER,1
		GOTO	$-2		

		DECFSZ	TIMER1,1
		GOTO	S1

		CALL	SUPRISE			;SUPRISE FACE
		DECFSZ	TIMER,1
		GOTO	$-2

		CALL	NO				;NO FACE
		DECFSZ	TIMER,1
		GOTO	$-2	

		CALL	DEVIL_SMILE		;DEVIL SMILE
		DECFSZ	TIMER,1
		GOTO	$-2
		
		CALL	SLANT_LT		;KISSING FACE
		DECFSZ	TIMER,1
		GOTO	$-2
		CALL	SLANT_RT
		DECFSZ	TIMER,1
		GOTO	$-2	
				

		CALL	DEVIL_MEAN
		DECFSZ	TIMER,1
		GOTO	$-2		

		GOTO	START			
		
	
;*******************************************************




HAPPY	CALL		CLEAR		
		BCF			C3			
		BSF			EE				;15
		CALL		CLEAR
		BCF			C3			
		BSF			FF				;20
		CALL		CLEAR
		BCF			C2
		BSF			EE				;15
		CALL		CLEAR	
		BCF			C2
		BSF			HH				;16							
		CALL		CLEAR	
		BCF			C3	
		BSF			DD				;13
		CALL		CLEAR
		BCF			C2
		BSF			DD				;8
		RETURN
		
SAD		CALL		CLEAR
		BCF			C3							
		BSF			GG				;21
		CALL		CLEAR
		BCF			C3				
		BSF			HH				;19
		CALL		CLEAR
		BCF			C2				
		BSF			FF				;20
		CALL		CLEAR
		BCF			C2			
		BSF			GG				;22
		CALL		CLEAR
		BCF			C1				
		BSF			FF				;23
		CALL		CLEAR
		BCF			C1
		BSF			GG				;24	
		RETURN			

;*********************************WINKING FACE
WINK_RT CALL		CLEAR		
		BTFSS		FLAG,0
		GOTO		WINKA
		BCF			C2
		BSF			DD
		CALL		CLEAR
		GOTO		WINK2
		
WINKA	BCF			C3
		BSF			DD
		CALL		CLEAR
		BCF			C2
		BSF			DD
		CALL		CLEAR


WINK2	BCF			C2
		BSF			HH
		CALL		CLEAR
		BCF			C3				
		BSF			FF
		CALL		CLEAR
		BCF			C2				
		BSF			EE
		CALL		CLEAR	
		BCF			C2				
		BSF			BB
		CALL		CLEAR		
		BCF			C2				
		BSF			AA
		CALL		CLEAR
		BCF			C3				
		BSF			CC
		CALL		CLEAR
		BCF			C1				
		BSF			AA
		CALL		CLEAR
		BCF			C1				
		BSF			DD
		CALL		CLEAR
		BCF			C1				
		BSF			HH
		CALL		CLEAR	
		BCF			C3
		BSF			EE
		CALL		CLEAR
		RETURN	
		
WINK_LT CALL		CLEAR		
		BTFSS		FLAG,0
		GOTO		WINKB
		BCF			C3
		BSF			DD
		CALL		CLEAR
		BCF			C1
		BSF			GG
		GOTO		WINKC
		
WINKB	CALL		CLEAR
		BCF			C2
		BSF			DD
		CALL		CLEAR
		BCF			C1
		BSF			FF
		CALL		CLEAR


WINKC	CALL		CLEAR
		BCF			C2			
		BSF			HH
		CALL		CLEAR
		BCF			C3			
		BSF			FF
		CALL		CLEAR
		BCF			C2			
		BSF			EE
		CALL		CLEAR	
		BCF			C2			
		BSF			BB
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C3			
		BSF			CC
		CALL		CLEAR
		BCF			C1		
		BSF			AA
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1			
		BSF			HH
		CALL		CLEAR
		BCF			C3
		BSF			EE
		CALL		CLEAR	
		RETURN	
DEVIL_SMILE
		CALL		CLEAR
		BCF			C1			
		BSF			FF
		CALL		CLEAR
		BCF			C1			
		BSF			GG
		CALL		CLEAR
		BCF			C2			
		BSF			HH
		CALL		CLEAR
		BCF			C3			
		BSF			FF
		CALL		CLEAR
		BCF			C2			
		BSF			EE
		CALL		CLEAR	
		BCF			C2			
		BSF			CC
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C3			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1			
		BSF			HH
		CALL		CLEAR	
		BSF			C3			
		BSF			BB
		CALL		CLEAR
		BCF			C3
		BSF			EE
		CALL		CLEAR
		BCF			C3		
		BSF			BB
		CALL		CLEAR
		BCF			C1
		BSF			BB
		CALL		CLEAR	
		RETURN	

DEVIL_MEAN		
		CALL		CLEAR
		BCF			C3			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			GG
		CALL		CLEAR
		BCF			C3			
		BSF			HH
		CALL		CLEAR
		BCF			C3
		BSF			GG
		CALL		CLEAR
		BCF			C2			
		BSF			FF
		CALL		CLEAR	
		BCF			C3			
		BSF			AA
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C2			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			EE
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1			
		BSF			CC
		CALL		CLEAR	
		BCF			C3			
		BSF			BB
		CALL		CLEAR
		BCF			C1			
		BSF			BB
		CALL		CLEAR	
		BCF			C1
		BSF			FF
		CALL		CLEAR
		BCF			C1
		BSF			GG
		CALL		CLEAR
		RETURN			
SLANT_LT
		CALL		CLEAR
		BCF			C3			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			DD
		CALL		CLEAR
		BCF			C3			
		BSF			HH
		CALL		CLEAR
		BCF			C3			
		BSF			HH
		CALL		CLEAR
		BCF			C3			
		BSF			GG
		CALL		CLEAR
		BCF			C2
		BSF			EE
		CALL		CLEAR	
		BCF			C3			
		BSF			AA
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C2			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			EE
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1			
		BSF			CC
		CALL		CLEAR	
		RETURN
SLANT_RT
		CALL		CLEAR
		BCF			C3				
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			DD
		CALL		CLEAR
		BCF			C3
		BSF			FF
		CALL		CLEAR
		BCF			C2			
		BSF			GG
		CALL		CLEAR
		BCF			C2			
		BSF			FF
		CALL		CLEAR	
		BCF			C2			
		BSF			BB
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C3			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			HH
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1				
		BSF			AA
		CALL		CLEAR	
		RETURN
SUPRISE
		CALL		CLEAR
		BCF			C1			
		BSF			FF
		CALL		CLEAR
		BCF			C2			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			EE
		CALL		CLEAR
		BCF			C3			
		BSF			HH
		CALL		CLEAR
		BCF			C2			
		BSF			FF
		CALL		CLEAR
		BCF			C3
		BSF			FF
		CALL		CLEAR	
		BCF			C2			
		BSF			BB
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C3			
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			AA
		CALL		CLEAR
		BCF			C1			
		BSF			DD
		CALL		CLEAR
		BCF			C1				
		BSF			HH
		CALL		CLEAR	
		RETURN
		
NO		CALL		CLEAR
		BCF			C3			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			DD
		CALL		CLEAR
		BCF			C2			
		BSF			EE
		CALL		CLEAR
		BCF			C3			
		BSF			HH
		CALL		CLEAR
		BCF			C2			
		BSF			FF
		CALL		CLEAR	
		BCF			C3
		BSF			FF
		CALL		CLEAR
		BCF			C3			
		BSF			AA
		CALL		CLEAR		
		BCF			C2			
		BSF			AA
		CALL		CLEAR
		BCF			C2				
		BSF			CC
		CALL		CLEAR
		BCF			C1			
		BSF			EE
		CALL		CLEAR
		BCF			C1				
		BSF			DD
		CALL		CLEAR
		BCF			C1			
		BSF			CC
		CALL		CLEAR	
		RETURN

			
CLEAR	DECFSZ		COUNTER,1		;DISPLAY DELAY
		GOTO		$-1
		MOVLW		B'10000011'
		MOVWF		PORTA
		CLRF		PORTB
		RETURN		
		
	END                       ; directive 'end of program'

